@@ -42,7 +42,7 @@ import java.util.logging.LoggingPermission;
 /**
  * A logging context, for producing isolated logging environments.
  */
-@SuppressWarnings("unused")
+@SuppressWarnings({"unused", "WeakerAccess"})
 public final class LogContext implements Protectable, AutoCloseable {
     private static final LogContext SYSTEM_CONTEXT = new LogContext(false);
 
@@ -318,6 +318,15 @@ public final class LogContext implements Protectable, AutoCloseable {
         logContextSelector = newSelector;
     }
 
+    /**
+     * Returns the currently set log context selector.
+     *
+     * @return the log context selector
+     */
+    public static LogContextSelector getLogContextSelector() {
+        return logContextSelector;
+    }
+
     @Override
     public void protect(Object protectionKey) throws SecurityException {
         if (protectKeyUpdater.compareAndSet(this, null, protectionKey)) {
